==> citrus-ws-4.0.2-sources.jar: org/citrusframework/model/testcase/ws/SendModel.java <==
//
// Diese Datei wurde mit der Eclipse Implementation of JAXB, v4.0.3 generiert 
// Siehe https://eclipse-ee4j.github.io/jaxb-ri 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
//


package org.citrusframework.model.testcase.ws;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlSchemaType;
import jakarta.xml.bind.annotation.XmlType;
import org.citrusframework.model.testcase.core.SendActionType;


/**
 * <p>Java-Klasse für SoapSendActionType complex type.
 * 
 * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
 * 
 * <pre>{@code
 * <complexType name="SoapSendActionType">
 *   <complexContent>
 *     <extension base="{http://www.citrusframework.org/schema/testcase}SendActionType">
 *       <sequence>
 *         <element name="attachment" type="{http://www.citrusframework.org/schema/ws/testcase}SoapAttachmentType" maxOccurs="unbounded" minOccurs="0"/>
 *       </sequence>
 *       <attribute name="mtom-enabled" type="{http://www.w3.org/2001/XMLSchema}anySimpleType" />
 *       <attribute name="soap-action" type="{http://www.w3.org/2001/XMLSchema}anySimpleType" />
 *       <attribute name="content-type" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="accept" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SoapSendActionType", propOrder = {
    "attachments"
})
@XmlRootElement(name = "send")
public class SendModel
    extends SendActionType
{

    @XmlElement(name = "attachment")
    protected List<SoapAttachmentType> attachments;
    @XmlAttribute(name = "mtom-enabled")
    @XmlSchemaType(name = "anySimpleType")
    protected String mtomEnabled;
    @XmlAttribute(name = "soap-action")
    @XmlSchemaType(name = "anySimpleType")
    protected String soapAction;
    @XmlAttribute(name = "content-type")
    protected String contentType;
    @XmlAttribute(name = "accept")
    protected String accept;

    /**
     * Gets the value of the attachments property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the Jakarta XML Binding object.
     * This is why there is not a {@code set} method for the attachments property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAttachments().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link SoapAttachmentType }
     * 
     * 
     * @return
     *     The value of the attachments property.
     */
    public List<SoapAttachmentType> getAttachments() {
        if (attachments == null) {
            attachments = new ArrayList<>();
        }
        return this.attachments;
    }

    /**
     * Ruft den Wert der mtomEnabled-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMtomEnabled() {
        return mtomEnabled;
    }

    /**
     * Legt den Wert der mtomEnabled-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMtomEnabled(String value) {
        this.mtomEnabled = value;
    }

    /**
     * Ruft den Wert der soapAction-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSoapAction() {
        return soapAction;
    }

    /**
     * Legt den Wert der soapAction-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSoapAction(String value) {
        this.soapAction = value;
    }

    /**
     * Ruft den Wert der contentType-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getContentType() {
        return contentType;
    }

    /**
     * Legt den Wert der contentType-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setContentType(String value) {
        this.contentType = value;
    }

    /**
     * Ruft den Wert der accept-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAccept() {
        return accept;
    }

    /**
     * Legt den Wert der accept-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAccept(String value) {
        this.accept = value;
    }

}

==> citrus-ws-4.5.2-sources.jar: org/citrusframework/model/testcase/ws/SendModel.java <==
//
// Diese Datei wurde mit der Eclipse Implementation of JAXB, v4.0.5 generiert 
// Siehe https://eclipse-ee4j.github.io/jaxb-ri 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
//


package org.citrusframework.model.testcase.ws;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlSchemaType;
import jakarta.xml.bind.annotation.XmlType;
import org.citrusframework.model.testcase.core.SendActionType;


/**
 * <p>Java-Klasse für SoapSendActionType complex type.</p>
 * 
 * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.</p>
 * 
 * <pre>{@code
 * <complexType name="SoapSendActionType">
 *   <complexContent>
 *     <extension base="{http://www.citrusframework.org/schema/testcase}SendActionType">
 *       <sequence>
 *         <element name="attachment" type="{http://www.citrusframework.org/schema/ws/testcase}SoapAttachmentType" maxOccurs="unbounded" minOccurs="0"/>
 *       </sequence>
 *       <attribute name="mtom-enabled" type="{http://www.w3.org/2001/XMLSchema}anySimpleType" />
 *       <attribute name="soap-action" type="{http://www.w3.org/2001/XMLSchema}anySimpleType" />
 *       <attribute name="content-type" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="accept" type="{http://www.w3.org/2001/XMLSchema}string" />
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SoapSendActionType", propOrder = {
    "attachments"
})
@XmlRootElement(name = "send")
public class SendModel
    extends SendActionType
{

    @XmlElement(name = "attachment")
    protected List<SoapAttachmentType> attachments;
    @XmlAttribute(name = "mtom-enabled")
    @XmlSchemaType(name = "anySimpleType")
    protected String mtomEnabled;
    @XmlAttribute(name = "soap-action")
    @XmlSchemaType(name = "anySimpleType")
    protected String soapAction;
    @XmlAttribute(name = "content-type")
    protected String contentType;
    @XmlAttribute(name = "accept")
    protected String accept;

    /**
     * Gets the value of the attachments property.
     * 
     * <p>This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the attachments property.</p>
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * </p>
     * <pre>
     * getAttachments().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link SoapAttachmentType }
     * </p>
     * 
     * 
     * @return
     *     The value of the attachments property.
     */
    public List<SoapAttachmentType> getAttachments() {
        if (attachments == null) {
            attachments = new ArrayList<>();
        }
        return this.attachments;
    }

    /**
     * Ruft den Wert der mtomEnabled-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMtomEnabled() {
        return mtomEnabled;
    }

    /**
     * Legt den Wert der mtomEnabled-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMtomEnabled(String value) {
        this.mtomEnabled = value;
    }

    /**
     * Ruft den Wert der soapAction-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSoapAction() {
        return soapAction;
    }

    /**
     * Legt den Wert der soapAction-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSoapAction(String value) {
        this.soapAction = value;
    }

    /**
     * Ruft den Wert der contentType-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getContentType() {
        return contentType;
    }

    /**
     * Legt den Wert der contentType-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setContentType(String value) {
        this.contentType = value;
    }

    /**
     * Ruft den Wert der accept-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAccept() {
        return accept;
    }

    /**
     * Legt den Wert der accept-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAccept(String value) {
        this.accept = value;
    }

}
